@@ -15,12 +15,11 @@
                                         output="order")){
 
 ##  if(!class(x)=="dist"){
-  if(all(class(x)!="dist")){
+##  if(all(class(x)!="dist")){
+  if(!inherits(x,"dist")){
     stop("x need to be of class dist")
   }
 
-
-
   .local_get_parameters <- function(parameter, defaults) {
     defaults <- as.list(defaults)
     parameter <- as.list(parameter)
